from django.conf.urls import url, include
from django.conf import settings
from django.conf.urls.static import static
from django.conf.urls import handler404

from wsgi.command import CommandView
from . import views

urlpatterns = [
    # main-view-scheme
    url(r'', include('wsgi.main.urls')),

    # certification views
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/$', views.certification, name='certification'),
    # url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/testing/$', views.certification_results, name='testing'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/dialog/$', views.certification_dialog, name='dialog'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/results/$', views.certification_results, name='results'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/progress/$', views.certification_progress, name='progress'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/submitted/$', views.certification_submitted, name='submitted'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/supportcases/$', views.certification_supportcases, name='supportcases'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/kbases/$', views.certification_kbases, name='kbases'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/multiHostResults/$', views.certification_multihost_results, name='multiHostResults'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<productID>[^\/]+)/productlogourl/$', views.certification_productLogoURL, name='productlogourl'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/comments/$', views.certification_comments, name='comments'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/attachments/$', views.certification_attachments, name='attachments'),
    url(r'^certification/cloud/(?P<certID>[^\/]+)/details/$', views.certification_cloud_details, name='cloud-details'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/details/$', views.certification_details, name='details'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/related/$', views.certification_related, name='related'),
    url(r'^certification/hardware/(?P<certID>[^\/]+)/publish/$', views.certification_hardware_publish, name='hardware-publish'),


    #  product specification from cert
    url(r'^certification/openstack/(?P<certID>[^\/]+)/specification/$', views.certification_openstack_specification, name='openstack-specification'),
    url(r'^certification/hardware/(?P<certID>[^\/]+)/specification/$', views.certification_hardware_specification, name='hardware-specification'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/specification/$', views.certification_specification, name='certification-specification'),
    url(r'^certification/cloud/(?P<certID>[^\/]+)/specification/details/$', views.certification_cloud_specification_details, name='cloud-specification-details'),
    url(r'^certification/hardware/(?P<certID>[^\/]+)/specification/details/$', views.certification_hardware_specification_details, name='hardware-specification-details'),
    url(r'^certification/hardware/(?P<certID>[^\/]+)/specification/sample/$', views.certification_hardware_specification_sample, name='hardware-specification-sample'),
    url(r'^certification/hardware/(?P<certID>[^\/]+)/specification/related/$', views.certification_hardware_specification_related, name='hardware-specification-related'),
    url(r'^certification/hardware/(?P<certID>[^\/]+)/specification/dialog/$', views.certification_hardware_specification_dialog, name='hardware-specification-dialog'),
    url(r'^certification/openstack/(?P<certID>[^\/]+)/specification/(?P<details>[^\/]+)/$', views.certification_openstack_specification_details, name='openstack-specification-details'),
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/specification/details/$', views.certification_specification, name='certification-specification-details'),

    # certification host results activities
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<host>[^\/]+)/(?P<time>[^\/]+)/results/$', views.activity_results, name='results'), # Results doc for a host,
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<host>[^\/]+)/(?P<time>[^\/]+)/testing/$', views.activity_testing, name='testing'), # Testing on a Host,
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<time>[^\/]+)/assign/$', views.activity_assign_multihost, name='assign-multihost'), # Assign results for a multihost run,
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<host>[^\/]+)/(?P<time>[^\/]+)/assign/$', views.activity_assign, name='assign'), # Assign results on a Host,
    url(r'^certification/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<time>[^\/]+)/assign/$', views.activity_assign, name='assign'), # Assign multihost results on a Host,

    # sandbox views
    url(r'^sandbox/(?P<program>[^\/]+)/(?P<sandboxID>[^\/]+)/$', views.sandbox, name='sandbox'),
    url(r'^sandbox/(?P<program>[^\/]+)/(?P<sandboxID>[^\/]+)/results/?$', views.sandbox_results, name='sandbox-results'),
    url(r'^sandbox/(?P<program>[^\/]+)/(?P<sandboxID>[^\/]+)/(?P<host>[^\/]+)/(?P<time>[^\/]+)/results/$', views.sandbox_activity_results, name='sandbox-activity-results'),
    url(r'^sandbox/(?P<program>[^\/]+)/(?P<sandboxID>[^\/]+)/(?P<host>[^\/]+)/(?P<time>[^\/]+)/testing/$', views.sandbox_activity_testing, name='sandbox-activity-testing'),

    # host services
    url(r'^hoststatus/(?P<host>[^\/]+)/(?P<connection>[^\/]+)/?$', views.hoststatus, name='hoststatus'), # HostStatus,
    url(r'^hostinteractive/(?P<host>[^\/]+)/(?P<connection>[^\/]+)/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/?$', views.hostinteractive, name='hostinteractive'), # HostInteractive,
    url(r'^hostresults/(?P<type>[a-z\-]+)/(?P<id>[^\/]+)/(?P<host>.+)/(?P<connection>.+)/(?P<activityURL>[^\/]+)/$', views.hostresults, name='hostresults'), # HostResults,
    # url(r'^hosttesting/(?P<type>[a-z]+)/(?P<id>[^\/]+)/(?P<host>.+)/(?P<connection>.+)/?$', views.hosttesting, name='hosttesting'), # HostTesting,
    url(r'^hostlog/(?P<host>[^\/]+)/(?P<connection>[^\/]+)/?$', views.hostlog, name='hostlog'), # HostLog,
    url(r'^hostremove/(?P<host>[^\/]+)/(?P<connection>[^\/]+)/(?P<program>[^\/]+)/(?P<certID>[^\/]+)/?$', views.hostremove, name='remove-host'),

    # services
    url(r'^interactive/?$', views.interactive, name='interactive'), # Interactive,
    url(r'^status/?$', views.status, name='status'), #Status,
    url(r'^results-xml?$', views.resultsXML, name='resultsXML'), # Results - old XSLT view

    # operations (wizards)
    url(r'^create/product/$', views.create_product, name='create-product'), # create a vendor product
    url(r'^create/certification/(?P<vendorID>[^\/]+)/(?P<productID>[^\/]+)/$', views.create_certification, name='create-certification'),
    url(r'^create/certification/$', views.create_certification, name='create-certification'), # create a certification
    url(r'^create/sandbox/(?P<vendorID>[^\/]+)/(?P<productID>[^\/]+)/$', views.create_sandbox, name='create-sandbox'), # create a sandbox (local certification)
    url(r'^create/sandbox/$', views.create_sandbox, name='create-sandbox'), # create a sandbox (local certification)
    url(r'^create/layered/certification/$', views.create_layered_cert, name="create-layered-cert"), # create a layered certification
    url(r'^create/supplemental/certification/$', views.create_supplemental_cert, name="create-supplemental-cert"), # create a supplemental certification
    url(r'^create/passthrough/certification/$', views.create_pass_through_cert, name="create-pass-through-cert"),

    # leverage
    url(r'^leverage/save/(?P<certID>[^\/]+)/(?P<compID>[^\/]+)/(?P<testID>[^\/]+)/$', views.leverage_save, name="leverage-save"),
    url(r'^leverage/get/$', views.leverage_get, name="leverage-get"),
    url(r'^leverage/apply/(?P<certID>[^\/]+)/(?P<compID>[^\/]+)/$', views.leverage_apply, name="leverage-apply"),
    url(r'^leverage/submit/(?P<certID>[^\/]+)/(?P<compID>[^\/]+)/(?P<leverageType>[^\/]+)/(?P<leverageID>[^\/]+)/$', views.leverage_submit, name="leverage-submit"),

    # get makes for a vendor creating a passthrough cert
    url(r'^makes/(?P<vendor_id>[^\/]+)/$', views.get_makes_by_vendor, name="makes"),

    # cwe
    url('cwe/', include('wsgi.cwe.urls')),

    # actions
    url(r'^addTest/?$', views.addTest, name='addTest'), # AddTest
    url(r'^clean/?$', views.clean, name='clean'),
    url(r'^test/(?P<type>[a-z\-]+)/(?P<id>[^\/]+)/?$', views.hosts, name='test'),
    url(r'^test/(?P<type>[a-z\-]+)/(?P<id>[^\/]+)/(?P<host>.+)/?$', views.test, name='test'),
    url(r'^delete/?$', views.delete, name='delete'), #Delete,
    url(r'^update/?$', views.update, name='update'), #Update,
    url(r'^update/product/$', views.update_product, name='update-product'), #Update a vendor product,
    url(r'^update/certification/$', views.update_certification, name='update-certification'), #Update a certification,
    url(r'^download/?$', views.download, name='download'), # Download,
    url(r'^mailto/?$', views.mailto, name='mailto'), # MailTo,
    url(r'^save/?$', views.save, name='save'), #Save,
    url(r'^submit/?$', views.submit, name='submit'), #Submit,
    url(r'^run/?$', views.run, name='run'), # Run,
    url(r'^download/attachment/(?P<certificationID>[^\/]+)/(?P<fileID>[^\/]+)/$', views.download_attachment, name="download-attachment"), #Download attachment from a certification
    url(r'^download/results/(?P<program>[^\/]+)/(?P<certificationID>[^\/]+)/(?P<fileID>[^\/]+)/$', views.download_results, name="download-results"), #Download results from a certification
    url(r'^upload/attachment/(?P<certificationID>[^\/]+)/$', views.upload_attachment, name="upload-attachment"), #Upload attachment to a certification
    url(r'^upload/logo/(?P<program>[^\/]+)/(?P<certificationID>[^\/]+)/$', views.upload_logo, name="upload-logo"), #Upload product logo from rhcert to Customer Portal
    url(r'^upload/results/(?P<program>[^\/]+)/(?P<certificationID>[^\/]+)/$', views.upload_results, name="upload-results"), #Upload results.xml to a cert

    # dev tools

    # url(r'^blank/?$', views.blank, name='blank'), # ": a content-free blank page

    # collaboration (calls made by individual tests)
    url(r'^collab/$', CommandView.as_view()),

     # React Backend URLs
    url(r'api/', include('wsgi.api.urls')),

] + static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)

handler404 = 'views.error_404'
