"""
Django settings for rhcertServer project.

Generated by 'django-admin startproject' using Django 1.8.2.

For more information on this file, see
https://docs.djangoproject.com/en/1.8/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.8/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
import base64
import django
from distutils.version import StrictVersion

from rhcert.environment import Environment
from rhcert.tags import ServerConfiguration

# SUB_SITE = "/rhcert/"
BASE_DIR = os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

CONFIGURATION = Environment().getServerConfiguration()

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.8/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
with open(os.path.join('/tmp', '.django-secret'), "rb") as file_:
    SECRET_KEY = str(base64.b64decode(file_.read()))

# SECURITY WARNING: don't run with debug turned on in production!

DEBUG = False if CONFIGURATION == ServerConfiguration.management else True

SESSION_ENGINE = "django.contrib.sessions.backends.file"
# gnichols added so REST api calls about login status are current.
SESSION_SAVE_EVERY_REQUEST = True
SESSION_COOKIE_HTTPONLY = False

# Hosts/domain names that are valid for this site.
# "*" matches anything, ".example.com" matches example.com and all subdomains
ALLOWED_HOSTS = ['*']

# CORS - need to install django-cors-headers
# Fedora 31/python2/django-1.11:
#   $python2 -m pip install django-cors-headers
# RHEL7:
#   there may be python-django-cors-headers rpm?
# them, enable corsheaders.middleware.CorsMiddleware
# in MIDDLEWHARE_CLASSES for this to have any effect
#  allow CORS from any origin
CORS_ORIGIN_ALLOW_ALL=True
# pass in credentials from origin
CORS_ALLOW_CREDENTIALS=True



# Application definition

INSTALLED_APPS = (
                  'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.messages',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.staticfiles',
                # 'corsheaders',
                  'application',
)

MIDDLEWARE_CLASSES = (
    # enable CORS headers:
    # 'corsheaders.middleware.CorsMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    # 'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    # 'django.contrib.auth.middleware.SessionAuthenticationMiddleware', not in django 1.6
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'application.middleware.UrlRouterMiddleware',
    'application.middleware.HttpRedirectMiddleware',
    # 'django.middleware.security.SecurityMiddleware', not in django 1.6
)

if StrictVersion(django.get_version()) >= StrictVersion('2.0'):
    MIDDLEWARE = MIDDLEWARE_CLASSES

ROOT_URLCONF = 'project.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'rhcert', 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'wsgi.labels.getLabelsDictionary',
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]


WSGI_APPLICATION = 'project.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.8/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}


# Internationalization
# https://docs.djangoproject.com/en/1.8/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.8/howto/static-files/

STATIC_URL = '/rhcert/'
STATIC_ROOT = "/var/www/rhcert"

import sys
import codecs
sys.stdout = codecs.getwriter('utf8')(sys.stdout)
sys.stderr = codecs.getwriter('utf8')(sys.stderr)

# Patternfly uses alert-danger for the error level style (gnichols, 5-8-2019)
from django.contrib.messages import constants as messages
MESSAGE_TAGS = {
    messages.ERROR: 'danger'
}

DATA_UPLOAD_MAX_MEMORY_SIZE = 209700000 # 200 MiB
FILE_UPLOAD_MAX_MEMORY_SIZE = DATA_UPLOAD_MAX_MEMORY_SIZE

