"""
WSGI config for server project.

It exposes the WSGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/1.8/howto/deployment/wsgi/
"""

import os
import string
import random
import base64
import io

from django.core.wsgi import get_wsgi_application
from rhcert.client.beacon import Beacon


def generate_secret_string():
    """
    This function will be used to generate the Django secret key used
    for crypto-signing cookies, sessions etc. in the django app

    Django secret keys are by default 50 characters, here generate a
    50 digit key by combining letters, digits and few punctuations
    """
    secret_combo = string.ascii_lowercase + string.digits + '!@#$%^&*(-_=+)'
    key = ''.join(random.choice(secret_combo) for i in range(0,49))

    # Check if file exists or else write a new encoded secret in it,
    # in case it exists check whether if it is zero size or else
    # write a new encoded secret in it.
    file_path = os.path.join('/tmp', '.django-secret')
    if not os.path.exists(file_path) or os.stat(file_path).st_size == 0:
        with io.open(file_path, 'wb') as file_:
            try: # python3
                encodedKey = base64.b64encode(bytes(key, encoding='utf-8'))
            except TypeError: # python2
                encodedKey = key.encode('base64')
            file_.write(encodedKey)

# Generate the Django secret key
generate_secret_string()

# run server beacon thread on startup:
Beacon("rhcert:server").start()

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "project.settings")

application = get_wsgi_application()


