# Copyright (c) 2018 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Zahid Ajaz
#
import cgi
from distutils.version import LooseVersion
from rhcert.version import name, version, release
from wsgi.api.api import API


class CWESupportedVersion(API):
    def __init__(self):
        API.__init__(self)

    def supportedMethods(self): return [API.GET]

    @staticmethod
    def packageVersion(package):
        # version = package.split("-", 2) # we want major.minor.release - just stript the "redhat-certification-"
        return LooseVersion(package)

    def get(self):
        self.getConnection()
        message = str()

        try:
            rhcert_package = "-".join([name, version, release ])
            if self.getParameter("nvr"): # overridde for testing
                rhcert_package = self.getParameter("nvr")
            response = self.getWorkflow().checkSupported(rhcert_package)
        except Exception as error:
            return self.errorResponse(error)

        if response:
            # Warn if result_source_package is unsupported or not the latest.
            if response["supported"] == 1:

                if self.packageVersion(rhcert_package) < self.packageVersion(response["current NVR"]):
                    message = ("The version of redhat-certification package you are using is {0} which is not the latest "
                                "and will expire on {1}. \nPlease upgrade to latest: {2}").format(
                                    rhcert_package, response["expires"], response["current NVR"])
            else:
                if self.packageVersion(rhcert_package) > self.packageVersion(response["current NVR"]):
                    message = ("The version of redhat-certification package you are using is {0} which is "
                                "unsupported. \nPlease use the current supported version: {1}").format(
                                    rhcert_package, response["current NVR"])
                else:
                    message = ("The version of redhat-certification package you are using is {0} which is "
                                "unsupported. \nPlease upgrade to the current supported version: {1}").format(
                                    rhcert_package, response["current NVR"])

            self.data = response
            self.data["message"] = cgi.escape(message)
            self.data["testing"] = rhcert_package
        else:
            # no message should appear re: support if not connected.
            self.data =  {"message": "", "supported": 0}

        return self.data

