# Copyright (c) 2019 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
from django.http import HttpResponse
from wsgi.connection import Connection
from wsgi.alert import Alert
from wsgi.api.api import API

class Login(API):
    """ User login/logout """

    def __init__(self):
        API.__init__(self)
        self.loginRequired = False

    def supportedMethods(self): return [API.PUT, API.DELETE]

    # login
    def put(self):

        if not self.getWorkflow().isReachable():
            # 503 - service unavailable
            return HttpResponse(status=503, reason = ", ".join(self.getWorkflow().getErrors()))

        self.getWorkflow().login(self.json.get("username"), self.json.get("password"))
        if self.getWorkflow().getErrors():
            # 401 - unauthorized
            print("Error: " + (", ".join(self.getWorkflow().getErrors())))
            return HttpResponse(status=401, reason = ", ".join(self.getWorkflow().getErrors()))


        # clear the previous failed login error alerts if any
        Alert.clearMessages(self.request)
        self.request.session.update(self.getWorkflow().getCredentials())
        self.data["redirect"] = self.getParameter("return-to") if self.getParameter("return-to") else '/'
        self.data['djangoSessionID'] = self.request.session.session_key
        return self.data

    # logout
    def delete(self):
        self.request.session.flush()
        self.getWorkflow().clearLogin()
        return {"logout": "success"}
