# Copyright (c) 2020 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#

from wsgi.api.api import API

from rhcert.tags import ServerConfiguration

class Product(API):

    def __init__(self):
        API.__init__(self)
        self.loginRequired = True
        self.productID = None

    def supportedMethods(self): return [API.GET]

    def serve(self, request, productID):
        self.productID = productID
        return super(Product, self).serve(request)

    def __getProduct(self):
        """ temporary - need a generic API that just takes a product ID """
        for vendor in  self.getConnection().getVendorProducts().getVendors():
            for product in vendor.getProducts():
                # filter out fake products created for naming sandboxes
                if product.getID() == self.productID:
                    return (vendor, product)
                if product.getID() < "1000":
                    continue

        # not found
        return (None, None)

    def get(self):
        (vendor, product) = self.__getProduct()
        if (vendor and product):
            self.data["vendor"] = vendor
            self.data["product"] = product
        else:
            # not found
            self.data["vendor"] = {}
            self.data["product"] = {}
        return self.data

