# Copyright (c) 2019 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#

from wsgi.api.api import API

from rhcert.tags import ServerConfiguration

class Products(API):
    """ presents the Products top-level UI page """

    def __init__(self):
        API.__init__(self)
        self.loginRequired = True

    def supportedMethods(self): return [API.GET]

    def get(self):
        products = list()
        for vendor in  self.getConnection().getVendorProducts().getVendors():
            for product in vendor.getProducts():
                # filter out fake products created for naming sandboxes
                if product.getID() < "1000":
                    continue
                products.append({"vendor": vendor, "product": product})
        # sort by vendor, product make and name
        self.data["products"] = sorted(products,
            key = lambda vendorProduct: (vendorProduct['vendor'].getName()
                                            +  vendorProduct['product'].getMake()
                                            + vendorProduct['product'].getName()))
        return self.data
