# Copyright (c) 2019 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols <gnichols@redhat.com>
#
import socket

import rhcert.version
from rhcert.tags import Tags, Constants, Sync
from rhcert.host import Host
from wsgi.api.api import API
import time
from datetime import datetime



class Status(API):
    def __init__(self):
        API.__init__(self)
        self.loginRequired = False

    def supportedMethods(self): return [API.GET, API.PUT]

    def __getClientIP(self):
        if self.request.META.get('HTTP_X_FORWARDED_FOR'):
            return self.request.META.get('HTTP_X_FORWARDED_FOR').split(',')[0]
        return self.request.META.get('REMOTE_ADDR')

    def get(self):
        self.getConnection()
        self.data[Constants.rhcert] = {
            Tags.version: rhcert.version.version,
            Tags.release: rhcert.version.release,
            Tags.hostname: socket.gethostname(),
            Constants.debug: "",
            "dialogOrder": "",
            "sync": "",
            "configuration": self.environment.getServerConfiguration(),
            "MaxDialogAttachmentSize": self.environment.getMaximumDialogAttachmentSize(),
            "username": self.getWorkflow().getCredentials().get("login"),
            "redhatCertificationNVR": "redhat-certification-" + rhcert.version.version + '-' + rhcert.version.release,
            "catalogURL": self.environment.getCatalogURL(),
            "servicesURL": self.environment.getServicesURL(),
            "clientConnection": Host(socket.gethostname()).getConnection(),
            "phase": self.environment.getPhase(),
            "ssoServer": self.environment.getSSOServer(),
            "catalogServer": self.environment.getCatalogServer(),
            "requestorIP": self.__getClientIP(),
            "status": "running",
            "multistore": self.environment.isMultiStoreEnabled(),
            "syncTime": "",
            "syncRange": ""
        }
        try:
            self.data[Constants.rhcert]["debug"] = self.getStore().getServerSettings().getDebug()
            self.data[Constants.rhcert]["dialogOrder"] = self.getStore().getServerSettings().getDialogOrder()
            self.data[Constants.rhcert]["sync"] = self.getStore().getServerSettings().getSyncStatus()
            self.data[Constants.rhcert]["syncRange"] = self.getStore().getServerSettings().getSyncRange()
            
            # Need to convert the syncTime from datetime timestamp into minutes.
            timeStamp = self.getStore().getServerSettings().getSyncTime()
            prettyTimeStamp = datetime.fromtimestamp(float(timeStamp))
            currentTimeStamp = datetime.now()
            timeDiff = currentTimeStamp - prettyTimeStamp
            self.data[Constants.rhcert]["syncTime"] = int(timeDiff.total_seconds() / 60)
        except Exception as error:
            # may have collided with sync process causing zero-length settomgs.xml file - log a warning
            print("Warning: could not access server settings:")
            print(error)
            pass

        return self.data

    def put(self):
        try:
            self.getConnection()
            serverSettings = self.getStore().getServerSettings()
            
            if self.json.get(Constants.debug):
                serverSettings.setDebug(self.json.get(Constants.debug))
            if self.json.get("dialogOrder"):
                serverSettings.setDialogOrder(self.json.get("dialogOrder"))
            if self.json.get("sync"):
                serverSettings.setSyncStatus(Sync.reset)
            if self.json.get("syncDateRange"):
                serverSettings.setSyncRange(self.json.get("syncDateRange"))

            # Save The server settings that we updated.
            serverSettings.save()

            # Return what we sent for update. 
            self.data = {
                "json": self.json
            }

            return self.data
        except Exception as e:
            return self.errorResponse("Error: Could not the server settings.  Error: %s" % (e))