# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Rajasi Kulkarni
#
# Implement wsgi to download attachment from a Certification Specification
import mimetypes
from django.shortcuts import render
from django.http import HttpResponseRedirect, HttpResponse, StreamingHttpResponse

from rhcert.workflow.config import Config

from ..view import View


class DownloadAttachment(View):
    """ Download attachment file from a Certification """

    def __init__(self):
        View.__init__(self)
        self.certificationID = None
        self.fileID = None

    def serve(self, request, template, certificationID, fileID):
        View.authenticate(self, request)
        self.template = template
        self.certificationID = certificationID
        self.fileID = fileID
        result = self.view(request)
        if type(result) != dict:
            return result
        return render(request, self.template, self.data)

    def view(self, request):
        View.view(self, request)
        self.cweResponse = self.getEngineWorkflow().downloadFileFromCertification(self.certificationID, self.fileID)
        if not self.getErrors() and self.cweResponse:
            data = self.cweResponse.get("data").decode("base64")
            response = HttpResponse(data, content_type=self.cweResponse.get("content_type"))
            response["Content-Disposition"] = "attachment; filename=\"%s\"" % self.cweResponse.get("file_name")
            response['Content-Length'] = self.cweResponse.get("size")
            (_, encoding) = mimetypes.guess_type(self.cweResponse.get("file_name"))
            response["Content-Encoding"] = encoding
            return response
