# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Rajasi Kulkarni
#
# Implement wsgi to upload attachment to a Certification
import mimetypes
from django.shortcuts import render
from django.http import HttpResponseRedirect, HttpResponse, StreamingHttpResponse

from rhcert.workflow.config import Config

from ..view import View
from ..alert import Alert


class UploadAttachment(View):
    """ Upload attachment file to a Certification """

    def __init__(self):
        View.__init__(self)
        self.certificationID = None

    def serve(self, request, template, certificationID):
        View.authenticate(self, request)
        self.template = template
        self.certificationID = certificationID
        result = self.view(request)
        if type(result) != dict:
            return result
        return render(request, self.template, self.data)

    def view(self, request):
        View.view(self, request)

        self.chosenFile = self.getParameter("chosenFile")

        self.cweFileResponse = self.getEngineWorkflow().uploadFileToCertification(self.certificationID,
                                                                                  self.getParameter("isSpec"),
                                                                                  self.getParameter("description"),
                                                                                  self.chosenFile.name,
                                                                                  self.chosenFile.read(),
                                                                                  self.chosenFile.content_type)
        if not self.getErrors() and self.cweFileResponse:
            Alert(Alert.success, "Attachment uploaded successfully", request)
        else:
            Alert(Alert.danger, "Error in attachment upload", request)
            Alert(Alert.danger, self.getEngineWorkflow().getErrors(), request)

        if self.getParameter("return-after"):
            return HttpResponseRedirect(self.getParameter("return-after"))
        return self.redirect("certifications")
