# Copyright (c) 2015 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#

from django.conf import settings
from rhcert.tags import ServerConfiguration
from .activityResults import Results


class Assign(Results):
    """ presents the results test plan assignment UI page """

    def __init__(self):
        Results.__init__(self)

    def view(self, request):
        if self.initializeView(request):
            self.__makeDefaultAssignments()
            result = self.__processForm()
            if result:
                return result
            self.__compileView()
        return self.data

    def __makeDefaultAssignments(self):
        # try and guess for any unassigned tests
        self.resultsDocument.assignComponents()
        # don't save the assignments here - save after processing the form

    def __compileView(self):
        self.data["results"] = {
                                "document": self.resultsDocument, 
                                "path": self.resultsPath,
                                "host": self.testHost,
                                }
        # since there appears to be no way in current django to loop over a range
        self.data["results"]["runs"] = list()
        for runNumber in range(self.resultsDocument.getNumberOfTestRuns()):
            self.data["results"]["runs"].append("%s" % (runNumber+1))

        self.data["results"]["tests"] = list()
        for test in self.resultsDocument.getTests():
            # any runs for this test?
            # if not test.wasRun():
            #    continue
            # for now, let's try to assign all tests to test plan components

            testDict = {"test": test, "runs": dict()}
            testDict.update(test.getTestParameters().getAll())
            # test spec with parameters are "<test path> [--<parameter> <value>]*"
            testSpec = test.getPath()
            for (parameter, value) in test.getTestParameters().getAll().items():
                testSpec += " --%s %s" % (parameter, value)
            testDict["testSpec"] = testSpec
            # testXMLQuery
            testXMLQuery = "?test=" + test.getPath() + "&amp;rpath=" + self.resultsPath
            if testDict.get("device"):
                testXMLQuery += "&amp;device=" + testDict.get("device")
            if testDict.get("udi"):
                testXMLQuery += "&amp;udi=" + testDict.get("udi")
            testDict["testXMLQuery"] = testXMLQuery

            for runNumber in range(self.resultsDocument.getNumberOfTestRuns()):
                testDict["runs"][runNumber+1] = test.getRun(runNumber+1)
            self.data["results"]["tests"].append(testDict)

    def __processForm(self):
        if self.getParameter("cancel"):
            return self.redirect("results", queryDict=None, 
                        paramList=[self.certificationProgram,  self.certificationID])

        if self.getParameter("submit") or self.getParameter("save"):
            updated = False
            self.data["assignments"] = self.getListParameter("assign")
            self.resultsDocument.reload() # get the unfiltered doc in case we update it
            for value in self.getListParameter("assign"):
                parts = value.split(":")
                if len(parts) != 2:
                    continue
                testPath = parts[0]
                componentID = parts[1]
                test = self.resultsDocument.getTest(testPath)
                if not test:
                    self.appendError("Error: test %s not found" % testPath)
                    continue
                if test.getPlanComponentID() != componentID:
                    test.setPlanComponentID(componentID)
                    updated = True
            if updated and not self.getErrors():
                self.resultsDocument.save()

            if not self.getErrors():
                if self.getParameter("submit"):
                    return self.redirect("submit", {"rpath": self.resultsPath})
                else: # save or ??
                    return self.redirect("results", queryDict=None, 
                            paramList=[self.program,  self.certificationID])

        return None # no redirect

