# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Pooja Tiwari
#

from rhcert.tags import Programs
from .certification import Certification


class HardwarePublish(Certification):
    """ presents the hardware certification publish UI page """

    def __init__(self):
        Certification.__init__(self)

    def serve(self, request, template, certID):
        self.program = Programs.hardware
        return Certification.serve(self, request, template, self.program, certID)

    def view(self, request):
        Certification.view(self, request)
        self.data["certificationTab"] = "publish"

        self.updateCWETestPlan()

        self.__showDeadline()

        self.__getPlanFeatureCategories()

        return self.data

    def __showDeadline(self):
        if self.data["certificationDetails"].get('deadline'):
            deadline = self.data["certificationDetails"]["deadline"].split('-')
            self.data["certificationDetails"]["publish_year"] = deadline[0]
            self.data["certificationDetails"]["publish_month"] = str(int(deadline[1])) # str(int('01')) => '1'
            self.data["certificationDetails"]["publish_day"] = str(int(deadline[2]))
        return self.data

    def __getPlanFeatureCategories(self):
        """ get plan components organized by category and feature, i.e.
            {
                "System": {
                    "Memory": {"components": [components], "status": "Confirmed" }
                    }
                "Network": {
                    "20 Gig Ethernet": {"components": [components], "status": "Not Confirmed" },
                    "Wireless N": {"components": [components], "status": "Confirmed" }
                }
            }
        """
        categories = {}
        for component in self.certification.getPlanComponents():
            for category, features in component.getFeatureCategories().items():
                for feature in features:
                    if not categories.get(category):
                        categories[category] = {}
                    if not categories[category].get(feature.getName()):
                        categories[category][feature.getName()] = {"components": [], "pass": 0, "fail": 0 }
                    categories[category][feature.getName()]["components"].append(component)
                    # totalize status
                    increment = "pass" if component.getStatus() == "Confirmed" else "fail"
                    categories[category][feature.getName()][increment] += 1
        # convert totals to ranges for use in template
        for category in categories.values():
            for feature in category.values():
                for total in ["pass", "fail"]:
                    feature[total] = range(feature[total])

        self.data["planFeatures"] = categories

