# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
from datetime import datetime

from rhcert.tags import Constants, Programs
from .specification import Specification


class SpecificationDialog(Specification):
    """ presents the a UI page, showing comments on the certification"""

    def __init__(self):
        Specification.__init__(self)

    def serve(self, request, template, tab, certID):
        self.tab = tab
        self.certID = certID
        self.program = Programs.hardware
        return Specification.serve(self, request, template, self.program, certID)

    def view(self, request):
        Specification.view(self, request)
        self.data["activeTab"] = "dialog"

        self.processForm()

        self.__compileActivityView()
        return self.data

    def __compileActivityView(self):
        self.data["certification"] = self.certification
        if self.getCertificationWorkflow().getErrors():
            self.appendErrors(self.getCertificationWorkflow().getErrors())
        self.data["comments"] = self.getCertificationWorkflow().getComments(self.certification, productComments=True)
        if self.getCertificationWorkflow.getErrors():
            self.appendErrors(self.getCertificationWorkflow().getErrors())
        # convert the time
        if self.data.get("comments"):
            for comment in self.data["comments"]:
                for parameter in ["creation_time", "time"]:
                    if comment.get(parameter):
                        comment[parameter] = datetime.strptime(str(comment.get(parameter)), Constants.UTCDATETIMEFORMAT)

    def processForm(self):
        if self.getParameter("newComment"):
            if self.getCertificationWorkflow().getErrors():
                self.appendErrors(self.getCertificationWorkflow().getErrors())
                return False
            self.data["cweResponse"] = self.getCertificationWorkflow().addComment(self.certification,
                                                                                  self.getParameter("newComment"),
                                                                                  productComments=True)
            if self.getCertificationWorkflow().getErrors():
                self.appendErrors(self.getCertificationWorkflow().getErrors())
                return False
        return True

