# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Anshul Behl
#

from rhcert.tags import Programs
from .specification import Specification


class RelatedSpecification(Specification):
    """ presents the a UI page, showing a vendor hardware specification for a  certification"""

    def __init__(self):
        Specification.__init__(self)

    def serve(self, request, template, tab, certID):
        self.tab = tab
        self.certID = certID
        self.program = Programs.hardware
        return Specification.serve(self, request, template, self.program, certID)

    def view(self, request):
        Specification.view(self, request)
        if not self.tab:
            self.data["activeTab"] = "summary"
        else:
            self.data["activeTab"] = self.tab
        self.__compileRelatedProducts()
        return self.data

    def __compileRelatedProducts(self):

        # The product needs to be updated as for a base product, pass through specs may have been created on the
        # same LTS after the base product is downloaded in store(default)/session (management)
        if not (self.product.getBaseProductID() or self.product.getPassThroughProductIDs()):
            self.getConnection().resetVendorProducts()
            self.getConnection().getVendorProducts()
            self.vendor, self.product = self.getConnection().getVendorProducts().getVendorProductByID(self.vendorID,
                                                                                                      self.productID)

        # pass-through products have base products
        if self.product.getBaseProductID():
            relatedCertifications = self.getCertificationWorkflow().getRelatedCertifications(self.certificationID)
            if not relatedCertifications:
                return None

            self.data["baseProductID"] = self.product.getBaseProductID()
            self.baseVendorID= relatedCertifications['parent_certification']['vendor_id']

            # self.vendorID is the vendor_id of the pass through vendor and
            # self.product.getBaseProductID() is the product_id of the base product
            # Here we do not have access to the base product's vendor_id, need API change request
            # The only solution currently is to make a API call to Cert.getRelatedCerts_5_9
            # and it will return base product details including the base product's vendor_id
            # can't fetch it only from store because it will break for management

            baseVendor, baseProduct = self.getConnection().getVendorProducts().getVendorProductByID(self.baseVendorID,
                                                                                                    self.product.getBaseProductID())
            self.data["baseVendor"] = baseVendor
            self.data["baseProduct"] = baseProduct
            if baseVendor and baseProduct:
                self.data["baseVendorID"] = baseVendor.getID()
                self.data["baseProductCertifications"] = self.getConnection().getVendorProductCertifications(baseProduct)

         # base products have pass-through products
        if self.product.getPassThroughProductIDs():
            self.data["passThroughProductIDs"] = self.product.getPassThroughProductIDs()
            self.data["passThroughProducts"] = list()
            for passThroughProductID in self.product.getPassThroughProductIDs():
                # Here self.vendorID is the vendor_id of the base product
                # Need to get vendor_id for each pass through product
                pass_through_product_details = self.getConnection().getVendorProductWorkflow().get(Programs.hardware,
                                                                                                   self.vendorID,
                                                                                                   passThroughProductID)
                passVendor, passProduct= self.getConnection().getVendorProducts().getVendorProductByID(pass_through_product_details['vendor_id'],
                                                                                                       passThroughProductID)

                if passVendor and passProduct:
                    certifications = self.getConnection().getVendorProductCertifications(passProduct)
                    self.data["passThroughProducts"].append((passVendor, passProduct, certifications))
