from django.conf.urls import url
from django.conf import settings
from django.conf.urls.static import static
from django.shortcuts import render

import wsgi.certification.specification as specification

from wsgi.certification.certification import Certification
from wsgi.certification.results import CertificationResults
from wsgi.certification.testing import Testing
from wsgi.certification.activityResults import Results
from wsgi.certification.progress import Progress
from wsgi.certification.submitted import Submitted
from wsgi.certification.supportcases import SupportCases
from wsgi.certification.kbases import KBases
from wsgi.certification.productlogo import ProductLogoURL
from wsgi.certification.attachments import Attachments
from wsgi.certification.comments import Comments
from wsgi.certification.assign import Assign
from wsgi.certification.dialog import Dialog
from wsgi.certification.details import Details
from wsgi.certification.related import Related
from wsgi.certification.specification.related import RelatedSpecification
from wsgi.certification.specification.dialog import SpecificationDialog
from wsgi.certification.hardware_publish import HardwarePublish
from wsgi.certification.cloudDetails import CloudDetails
from wsgi.certification.specification.specification import Specification
from wsgi.certification.specification.cloud import Cloud as CloudSpecification
from wsgi.certification.specification.hardware import Hardware as HardwareSpecification
from wsgi.certification.specification.openstack import OpenStack as OpenStackSpecification
from wsgi.certification.leverage import LeverageDialog
from wsgi.certification.upload import UploadResults
from wsgi.certification.download import DownloadResults
from wsgi.certification.download import MultiHostResults

def certification (request, program, certID):
    return Certification().serve(request, 'certification/certification.html', program, certID)

def progress(request, program, certID):
    return Progress().serve(request, 'certification/progress.html', program, certID)

def submitted(request, program, certID):
    return Submitted().serve(request, 'certification/submitted.html', program, certID)

def supportcases(request, program, certID):
    return SupportCases().serve(request, 'certification/supportcases.html', program, certID)

def kbases(request, program, certID):
    return KBases().serve(request, 'certification/kbases.html', program, certID)

def multiHostResults(request, program, certID):
    return MultiHostResults().serve(request, 'certification/multihost-results.html', program, certID)

def productLogoURL(request, program, certID, productID):
    return ProductLogoURL().serve(request, 'certification/productlogourl.html', program, certID, productID)

def comments(request, program, certID):
    return Comments().serve(request, 'certification/comments.html', program, certID)

def attachments(request, program, certID):
    return Attachments().serve(request, 'certification/attachments.html', program, certID)

def dialog(request, program, certID):
    return Dialog().serve(request, 'certification/dialog.html', program, certID)

def details(request, program, certID):
    return Details().serve(request, "certification/details/details.html", program, certID)

def related(request, program, certID):
    return Related().serve(request, "certification/related.html", program, certID)

def hardware_publish(request, certID):
    return HardwarePublish().serve(request, 'certification/hardware_publish.html', certID)

def cloud_details(request, certID):
    return CloudDetails().serve(request, "certification/details/cloud.html", certID)

def specification(request, program, certID):
    return Specification().serve(request, "certification/specification/specification.html", program, certID)

def openstack_specification(request, certID):
    return OpenStackSpecification().serve(request, "certification/specification/openstack.html", "", certID)

def hardware_specification(request, certID):
    return HardwareSpecification().serve(request, "certification/specification/hardware.html", "", certID)

# specification details by program
def hardware_specification_details(request, certID):
    return specification.details.hardware.Hardware().serve(request, "certification/specification/details/hardware.html", certID)
def cloud_specification_details(request, certID):
    return specification.details.cloud.Cloud().serve(request, "certification/specification/details/cloud.html", certID)
def openstack_specification_details(request, certID, details):
    return specification.details.openstack.OpenStack().serve(request, "certification/specification/details/openstack.html", certID, details)

def hardware_specification_sample(request, certID):
    return HardwareSpecification().serve(request, "certification/specification/sample.html", "sample", certID)

def hardware_specification_related(request, certID):
    return RelatedSpecification().serve(request, "certification/specification/related.html", "related", certID)

def hardware_specification_dialog(request, certID):
    return SpecificationDialog().serve(request, "certification/specification/dialog.html", "dialog", certID)

def results(request, program, certID):
    return CertificationResults().serve(request, 'certification/results.html', program, certID)

def testing(request, program, certID):
    return CertificationResults().serve(request, 'certification/testing.html', program, certID)

def activity_results(request, program, certID, host, time):
    return Results().serve(request, 'certification/activity-results.html', program, certID, host, time)

def activity_testing(request, program, certID, host, time):
    return Testing().serve(request, 'certification/activity-testing.html', program, certID, host, time)

def activity_assign(request, program, certID, host, time):
    return Assign().serve(request, 'certification/activity-assign.html', program, certID, host, time)

urlpatterns = [
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/$', certification, name='certification'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/dialog/$', dialog, name='dialog'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/results/$', results, name='results'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/progress/$', progress, name='progress'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/submitted/$', submitted, name='submitted'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/supportcases/$', supportcases, name='supportcases'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/kbases/$', kbases, name='kbases'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/multiHostResults/$', multiHostResults, name='multiHostResults'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<productID>[^\/]+)/productlogourl/$', productLogoURL, name='productlogourl'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/comments/$', comments, name='comments'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/attachments/$', attachments, name='attachments'),
    url(r'^cloud/(?P<certID>[^\/]+)/details/$', cloud_details, name='cloud-details'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/details/$', details, name='details'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/related/$', related, name='related'),
    url(r'^hardware/(?P<certID>[^\/]+)/publish/$', hardware_publish, name='hardware-publish'),


    #  product specification from cert
    url(r'^openstack/(?P<certID>[^\/]+)/specification/$', openstack_specification, name='openstack-specification'),
    url(r'^hardware/(?P<certID>[^\/]+)/specification/$', hardware_specification, name='hardware-specification'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/specification/$', specification, name='certification-specification'),
    url(r'^cloud/(?P<certID>[^\/]+)/specification/details/$', cloud_specification_details, name='cloud-specification-details'),
    url(r'^hardware/(?P<certID>[^\/]+)/specification/details/$', hardware_specification_details, name='hardware-specification-details'),
    url(r'^hardware/(?P<certID>[^\/]+)/specification/sample/$', hardware_specification_sample, name='hardware-specification-sample'),
    url(r'^hardware/(?P<certID>[^\/]+)/specification/related/$', hardware_specification_related, name='hardware-specification-related'),
    url(r'^hardware/(?P<certID>[^\/]+)/specification/dialog/$', hardware_specification_dialog, name='hardware-specification-dialog'),
    url(r'^openstack/(?P<certID>[^\/]+)/specification/(?P<details>[^\/]+)/$', openstack_specification_details, name='openstack-specification-details'),
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/specification/details/$', specification, name='certification-specification-details'),

    # certification host results activities
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<host>[^\/]+)/(?P<time>[^\/]+)/results/$', views.activity_results, name='results'), # Results doc for a host,
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<host>[^\/]+)/(?P<time>[^\/]+)/testing/$', views.activity_testing, name='testing'), # Testing on a Host,
    url(r'^(?P<program>[^\/]+)/(?P<certID>[^\/]+)/(?P<host>[^\/]+)/(?P<time>[^\/]+)/assign/$', views.activity_assign, name='assign'), # Assign results on a Host,
]