# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols <gnichols@redhat.com>
#
# Implementation of the wsgi for deleting test results/certification documents

import time
from django.shortcuts import render

from rhcert.compatability import XmlrpcServerProxy
from rhcert.tags import Tags, Constants
from rhcert.model.task import Task
from rhcert.model.resultsdocument import ResultsDocument
from rhcert.host import Host

from .view import View


class Clean(View):
    def __init__(self):
        View.__init__(self)
        self.type = None
        self.document = None
        self.path = None
        self.host = None

    def serve(self, request, template):
        View.authenticate(self, request)
        result = self.view(request)
        if type(result) != dict:
            return result
        # otherwise
        return render(request, template, result)

    def view(self, request):
        View.view(self, request)
        self.host = Host(self.getParameter("hostname"), self.getParameter("hostconnection"))
        self.data["host"] = self.host
        self.path = self.getParameter("rpath")
        self.data["rhcert"]["debug"] = "low"

        error = ""
        (self.type, self.document) = self.getStore().getCertificationInfo(self.path, error)
        if error:
            self.appendError(error)
        else:
            self.data["document"] = self.document
            self.data["rpath"] = self.path

        if self.getParameter("confirmed"):
            self.close()

        if not self.getErrors() and (self.getParameter("cancelled") or self.getParameter("confirmed")):
            return self.redirect("results", queryDict=None,
                                paramList=[self.document.getCertificationProgram(),  self.document.getCertificationID()])

        # otherwise, show the confirmation page
        return self.data

    def close(self):
        try:
            task = Task(Task.clean)
            task.setParameter(Task.server, self.getHostName())
            self.server = XmlrpcServerProxy(('http://%s:%s' % (self.host.getConnection(), self.environment.getServerListenerPort())), allow_none=True)
            self.result = self.server.run(task.toXML())
            # wait a couple seconds in hopes that it's ready
            time.sleep(2)
            if not self.result:
                self.appendError("Error: Close Request Failed.")
            else:
                self.result = self.server.getResult()
                if self.result:
                    self.data["result"] = self.result

        except Exception as exception:
            self.appendError("Error: Close Request Failed.")
            self.appendError("%s\n" % exception)

        if not self.getErrors():
            # reload the complete document
            self.document = ResultsDocument()
            self.document.load(self.path)
            self.document.setState(Constants.closed)
            self.document.save(self.path)



