# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Rajasi Kulkarni
#
import json

from rhcert.tags import Programs, Constants, SystemCategories
from .create import Create
from ..alert import Alert


class CreatePassThroughCert(Create):

    def __init__(self):
        Create.__init__(self)

    def view(self, request):
        result = Create.view(self, request)
        if type(result) != dict:
            return result

        self.certificationID = self.getParameter("certificationID")
        self.vendorID = self.getParameter("vendorID")
        self.productID = self.getParameter("productID")
        self.redhatProductID = self.getParameter("redhatProductID")
        self.redhatProductVersionID = self.getParameter("redhatProductVersionID")
        self.program = Programs.hardware

        if self.definingPassThroughProduct():
            return self.data


        return self.createPassThrough()

    def definingPassThroughProduct(self):
        if self.getParameter('next-button'):
            return False

        self.data["public_vendors"] = self.getCertificationWorkflow().getPublicVendors(Programs.hardware)
        self.data["systemCategories"] = SystemCategories.getAll()
        self.template = "create/define-passthrough.html"
        self.data["nextButtonValue"] = "done"
        self.data["createTitle"] = "New Pass-Through Product"
        self.data["createDescription"] = "Define a new Product for Pass-Through"
        self.data["nextButtonLabel"] = "Create"
        self.data["certificationID"] = self.certificationID
        return True


    def createPassThrough(self):
        parameters = self.getPostDictionary()
        vendor_parameter = json.loads(parameters.get('vendor'))
        parameters['vendor'] = vendor_parameter.get("vendor_name")
        if parameters['vendor_make_new']:
            parameters['make'] = parameters['vendor_make_new']
        else:
            parameters['make'] = parameters['vendor_make']
        if 'specification_status' in parameters:   #if key exists change to int as spec wants
            parameters['specification_status'] = int(parameters['specification_status'])

        self.cweResponse = self.getCertificationWorkflow().createPassThroughSpecification(self.certificationID, parameters)

        if not self.cweResponse or self.getCertificationWorkflow().getErrors():
            Alert(Alert.danger, "Error in creating Passthrough Specification", self.request)
            self.appendErrors(self.getCertificationWorkflow().getErrors())
            return self.redirect("related", queryDict=None,paramList=[self.program, self.certificationID])

        # otherwise
        Alert(Alert.success,"Created new Passthrough Product with ID : " + str(self.cweResponse.get("product_id")), self.request)

        # create the pass-through certification
        cweResponse = self.getCertificationWorkflow().createPassThroughCertification(self.cweResponse['product_id'], self.certificationID)
        if not cweResponse or self.getCertificationWorkflow().getErrors():
            Alert(Alert.danger, "Error in creating Passthrough Certification", self.request)
            self.appendErrors(self.getCertificationWorkflow().getErrors())
            return self.redirect("related", queryDict=None, paramList=[self.program, self.certificationID])

        # otherwise
        passthroughCertID = cweResponse['certification_id']
        Alert(Alert.success, "Created Passthrough Certification with ID : " + str(passthroughCertID), self.request)
        return self.redirect("certification", queryDict=None, paramList=[self.program,  passthroughCertID])

