# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Rajasi Kulkarni
#

from rhcert.tags import Programs, Constants
from .create import Create
from ..alert import Alert


class CreateSupplementalCert(Create):
    """ presents the a UI page, showing comments on the certification"""

    def __init__(self):
        Create.__init__(self)

    def view(self, request):
        result = Create.view(self, request)
        if type(result) != dict:
            return result

        self.certificationID = self.getParameter("certificationID")

        if self.confirming():
            return self.data

        response = self.getCertificationWorkflow().createSupplimentalCertification(self.certificationID)
        if not response or self.getCertificationWorkflow().getErrors():
            Alert(Alert.danger, "Error in creating Supplemental Certification", request)
            self.appendErrors(self.getCertificationWorkflow().getErrors())
            Alert(Alert.info,
                  "Please ensure that new product information has been supplied on the Product Details tab as\
                   an attachment and is processed by Red Hat.",
                  request)
            return self.redirect("related", queryDict=None, paramList=[Programs.hardware, self.certificationID])

        supplemental_cert_id = response.get("certification_id")
        # Go to the new supplemental cert
        Alert(Alert.success, "Created Supplemental Certification with ID : " + str(supplemental_cert_id), self.request)
        return self.redirect("certification", queryDict=None, paramList=[Programs.hardware, supplemental_cert_id])


    def confirming(self):
        if self.getParameter("next-button") == "confirmed":
            return False

        self.template = "create/confirm-supplemental.html"
        self.data["nextButtonValue"] = "confirmed"
        self.data["createTitle"] = "New Supplemental Certification"
        self.data["createDescription"] = "Specify Supplemental Components"
        self.data["nextButtonLabel"] = "Continue"
        self.data["certificationID"] = self.certificationID
        self.data["certificationProgram"] = Programs.hardware
        return True
