# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols 
#
import socket

from rhcert.tags import Constants
from rhcert.model.task import Task
from rhcert.host import Host

from .view import View


class HostInteractive(View):

    def __init__(self):
        View.__init__(self)

    def view(self, request, host, connection, certificationProgram, certificationID):
        self.request = request
        self.host = Host(host, connection)
        self.certificationProgram = certificationProgram
        self.certificationID = certificationID
        self.hostStatus = None
        self.hostInfo = None
        self.data = dict()
        if self.host.isValid():
            self.viewHostStatus()
        return self.data

    def viewHostStatus(self):
        self.getConnection(self.request) # data connection to store
        self.data["host"] = self.host
        (self.hostStatus, self.hostInfo) = self.getHostStatus(self.host)
        if self.hostStatus == "status":
            self.data["message"] = self.hostInfo
        elif self.hostStatus == "task":
            task = self.hostInfo
            self.data["task"] = task.getParametersDictionary()
            self.data["certificationProgram"] = self.certificationProgram
            self.data["certificationID"] = self.certificationID
            (self.certificationPath, self.certification) = self.getStore().getCertification(self.certificationProgram, self.certificationID)
            self.data["certification"] = self.certification
            self.data["parentURL"] = "results"
            self.data["thisURL"] = "testing"
            if self.certification.isSandbox():
                self.data["parentURL"] = "sandbox-results"
                self.data["thisURL"] = "sandbox-activity-testing"
                self.data["isSandbox"] = True
            if self.certificationID == task.getParameter("certificationID") and self.certificationProgram == task.getParameter("certificationProgram"):
                self.data["onThisCertification"] = True

            if not "default" in self.data["task"]:
                self.data["task"]["default"] = ""
            if self.data["task"]["default"].count('\n') > 1:
                self.data["task"]["multiline"] = self.data["task"]["default"].count('\n')

            if task.getTask() == Task.message:
                self.data["message"] = task.getParameter(Task.message)
            else:
                self.data["interactive"] = True
                self.data["question"] = task.getParameter(Task.question)
            if self.request.GET.get("xml"):
                self.data["xml"] = task.toXML()

            self.__viewHostTesting()
        else:
            self.data["status"] = self.hostStatus
            self.data["message"] = self.hostInfo

    def __viewHostTesting(self):
        # don't show any buttons for multi-host testing
        if self.certification.isMultiHost():
            return
        self.resultsDocuments = None
        if self.certification:
            self.resultsDocuments = self.getStore().getResultsDocumentsFor(self.certification, skipEmpty=False, host=self.host)
        if self.resultsDocuments:
            latestPath = sorted(self.resultsDocuments.keys(), reverse=True)[0]
            self.data["latest"] = {"document": self.resultsDocuments[latestPath], "path": latestPath}
        if self.__isReady(self.data.get("message")):
            if self.data.get("latest") and self.data["latest"]["document"].getState() != Constants.closed:
                self.data["showContinue"] = True
            else:
                self.data["showCreateNewFile"] = True

    def __isReady(self, message):
        self.data["message"] = message
        ready =  message and (message == "ready" or "Finished" in message or ("clean" in message and "succeeded" in message))
        if ready:
            self.data["ready"] = True
        return ready    



 


