# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols 
#
import socket
from rhcert.compatability import XmlrpcServerProxy
from rhcert.host import Host
from rhcert.client.client import RHCertClient

from .view import View

class HostLog(View):

    def __init__(self):
        View.__init__(self)

    def view(self, request, hostname, connection):
        result = View.view(self, request)
        if type(result) != dict:
            return result
        limit = self.getParameter("limit")
        try:
            lines = int(limit)
        except:
            lines = 15 # default
        if hostname:
            host = Host(hostname, connection)
            if host.isValid():
                log = self.getHostLog(host)
                if log:
                    logLines = log.splitlines()
                    self.data["log"] = ("\n".join(logLines[-lines:]))
        else:
            self.appendError("missing host parameter")

        return self.data

    def getHostLog(self, host, timeout=5):
        """  host is a Host object, timeout = 5 # sec """
        client = RHCertClient(host, timeout, self.environment)
        return client.getLog()


