# Copyright (c) 2018 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Shreyas Patil
#
import os

from rhcert.host import Host
from rhcert.tags import Constants
from .hoststatus import HostStatus
from django.http import JsonResponse


class HostRemove(HostStatus):

    def __init__(self):
        HostStatus.__init__(self)

    def view(self, request, host, connection, program, certification_id):
        HostStatus.view(self, request, host, connection)

        self.store = self.connection.getStore()

        status = False
        _, certification = self.store.getCertification(program, certification_id)
        base_url = Constants.sandbox if certification.isSandbox() else Constants.certification
        url = os.path.join('/', base_url, program, certification_id, 'results')
        if not certification:
            self.appendError("Error: could not locate %s certification id %s" % (program, certification_id))
            return JsonResponse(data={"status": status, "href": url})
        if not self.host.isValid():
            self.appendError("Error: Host {} specified is invalid".format(self.host.name))
            return JsonResponse(data={"status": status, "href": url})

        result_document = self.store.getResultsDocumentsFor(certification, skipEmpty=False, host=self.host)
        for path in result_document.keys():
            if not path or not self.store.deleteResults(path):
                break
        else:
            status = True

        return JsonResponse(data={"status": status, "href": url})