# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols 
#
from rhcert.host import Host
from rhcert.tags import Constants

from .hoststatus import HostStatus


class HostResults(HostStatus):

    def __init__(self):
        HostStatus.__init__(self)

    def view(self, request, program, id, host, connection, activityURL):
        self.data = HostStatus.view(self, request, host, connection)

        self.request = request
        self.certificationProgram = program
        self.certificationID = id
        self.host = Host(host, connection)

        self.data["host"] = self.host
        self.data["activityURL"] = activityURL

        (certificationPath, self.certification) = self.getConnection(request).getStore().getCertification(self.certificationProgram, self.certificationID)
        if not self.certification:
            self.appendError("Error: could not locate %s certification id %s" % (self.certificationProgram, self.certificationID))

        if self.certificationID and self.certificationProgram and self.certification:
            self.data["certification"] = self.certification
            self.data["certificationPath"] = certificationPath
            status = self.data.get("status")
            if status and self.certificationID == status.get("certificationID") and self.certificationProgram == status.get("certificationProgram"):
                self.data["onThisCertification"] = True

            # vendor and product
            vendors = self.certification.getVendors(notRedHat=True)
            if vendors:
                self.vendor = vendors[0]
                self.data["vendor"] = self.vendor
                products = self.vendor.getProducts()
                if products:
                    self.product = products[0]
                    self.data["product"] = self.product

            self.__viewHostResults()

        return self.data

    

    def __viewHostResults(self):
        self.resultsDocuments = self.getStore().getResultsDocumentsFor(self.certification, skipEmpty=False, host=self.host)
        resultsDocuments = list()
        for path in sorted(self.resultsDocuments.keys(), reverse=True):
            if not self.data.get("latest"):
                self.data["latest"] = self.resultsDocuments[path]
            resultsDocumentData = dict()
            resultsDocumentData["path"] = path
            resultsDocumentData["document"] = self.resultsDocuments[path]
            resultsDocuments.append(resultsDocumentData)
        self.data["resultsDocuments"] = resultsDocuments



