# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols 
#
import socket

from rhcert.tags import Constants
from rhcert.model.task import Task
from rhcert.host import Host

from .view import View


class HostStatus(View):

    def __init__(self):
        View.__init__(self)

    def view(self, request, host, connection):
        self.request = request
        self.status = dict()
        self.host = Host(host, connection)
        if not self.host.isValid():
            return {}

        # otherwise
        self.getConnection(request)  # get data connection
        self.viewHostStatus()
        return {"host": self.host, "status": self.status}

    def viewHostStatus(self):
        (statusType, info) = self.getHostStatus(self.host)
        if statusType == "status":
            self.status["message"] = info
        elif statusType == "task":
            task = info
            self.status["type"] = "task"
            self.status["certificationProgram"] = task.getParameter(Task.certificationProgram)
            self.status["certificationID"] = task.getParameter(Task.certificationID)
            if task.getTask() == Task.message:
                self.status["message"] = task.getParameter(Task.message)
            else:
                self.status["interactive"] = True
                self.status["host"] = self.host
                self.status["question"] = task.getParameter(Task.question)
            if self.request.GET.get("xml"):
                self.status["xml"] = task.toXML()
        else:
            self.status["status"] = statusType
            self.status["message"] = info

 


