# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols 
#
from rhcert.host import Host
from rhcert.tags import Constants

from .hoststatus import HostStatus


class HostTesting(HostStatus):

    def __init__(self):
        HostStatus.__init__(self)

    def view(self, request, program, id, host, connection):
        self.hostData = HostStatus.view(self, request, host, connection)

        self.certificationProgram = program
        self.certificationID = id

        (certificationPath, self.certification) = self.getStore().getCertification(self.certificationProgram, self.certificationID)
        if not self.certification:
            self.appendError("Error: could not locate %s certification id %s" % (self.certificationProgram, self.certificationID))

        if self.certificationID and self.certificationProgram and self.certification:
            self.hostData["certification"] = self.certification
            self.hostData["certificationPath"] = certificationPath
            if self.certificationID == self.hostData["status"].get("certificationID") and self.certificationProgram == self.hostData["status"].get("certificationProgram"):
                self.hostData["onThisCertification"] = True
            # vendor and product
            vendors = self.certification.getVendors(notRedHat=True)
            if vendors:
                self.vendor = vendors[0]
                self.hostData["vendor"] = self.vendor
                products = self.vendor.getProducts()
                if products:
                    self.product = products[0]
                    self.hostData["product"] = self.product

            self.__viewHostTesting()

        return self.hostData

    def __viewHostTesting(self):
        self.resultsDocuments = self.getStore().getResultsDocumentsFor(self.certification, skipEmpty=False, host=self.host)
        if self.resultsDocuments:
            latestPath = sorted(self.resultsDocuments.keys(), reverse=True)[0]
            self.hostData["latest"] = {"document": self.resultsDocuments[latestPath], "path": latestPath}
        if self.__isReady(self.hostData["status"].get("message")):
            if self.hostData.get("latest") and self.hostData["latest"]["document"].getState() != Constants.closed:
                self.hostData["showContinue"] = True
            else:
                self.hostData["showCreateNewFile"] = True

    def __isReady(self, message):
        ready =  message and (message == "ready" or "Finished" in message or ("clean" in message and "succeeded" in message))
        if ready:
            self.hostData["ready"] = True
        return ready

