
# Copyright (c) 2018 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#

from wsgi.include.widget import Widget

class TestSelector(Widget):
    def __init__(self, hostDocument, resultsDocument, resultsPath):
        Widget.__init__(self)
        self.hostDocument = hostDocument
        self.resultsDocument = resultsDocument
        self.resultsPath = resultsPath

    def getTemplate(self):
        return "include/test-selector.html"

    def amend(self):
        self.context = {
                "host": self.hostDocument,
                "document": self.resultsDocument,
                "path": self.resultsPath,
                "runs": [],
                "tests": [],
        }
        # since there appears to be no way in current django to loop over a range
        # make a list of "1", "2", "3", etc.
        for runNumber in range(self.resultsDocument.getNumberOfTestRuns()):
            self.context["runs"].append("%s" % (runNumber+1))

        for test in self.resultsDocument.getTests():
            testDict = {"test": test, "runs": dict()}
            testDict.update(test.getTestParameters().getAll())
            # test spec with parameters are "<test path> [--<parameter> <value>]*"
            testSpec = test.getPath()
            for (parameter, value) in test.getTestParameters().getAll().items():
                testSpec += " --%s %s" % (parameter, value)
            testDict["testSpec"] = testSpec
            # testXMLQuery
            testXMLQuery = "?test=" + test.getPath() + "&amp;rpath=" + self.resultsPath
            if testDict.get("device"):
                testXMLQuery += "&amp;device=" + testDict.get("device")
            if testDict.get("udi"):
                testXMLQuery += "&amp;udi=" + testDict.get("udi")
            testDict["testXMLQuery"] = testXMLQuery

            for runNumber in range(self.resultsDocument.getNumberOfTestRuns()):
                testDict["runs"][runNumber+1] = test.getRun(runNumber+1)
            self.context["tests"].append(testDict)
        return self.context