# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Rajasi Kulkarni
#
# Implement wsgi to upload logo to a Product
import mimetypes
from django.shortcuts import render
from django.http import HttpResponseRedirect, HttpResponse, StreamingHttpResponse

from rhcert.workflow.config import Config

from ..view import View
from ..alert import Alert


class UploadLogo(View):
    """ Upload logo to a product """

    def __init__(self):
        View.__init__(self)

    def serve(self, request, template, program, certificationID):
        View.authenticate(self, request)
        self.template = template
        self.program = program
        self.certificationID = certificationID
        result = self.view(request)
        if type(result) != dict:
            return result
        return render(request, self.template, self.data)

    def view(self, request):
        View.view(self, request)
        self.vendorID = self.getParameter("vendorID")
        self.productID = self.getParameter("productID")
        self.logo = self.getParameter("logo")
        self.vendor = self.getConnection().getVendorProducts().getVendorByID(self.vendorID)
        self.product = self.vendor.getProduct(self.productID)
        self.cweResponse = self.getVendorProductWorkflow().uploadProductLogo(self.program,
                                                                       self.product.getNodeID(),
                                                                       self.logo.content_type,
                                                                       self.logo.read())
        if not self.getErrors() and self.cweResponse:
            Alert(Alert.success, "Product logo updated successfully", request)
        else:
            Alert(Alert.danger, "Error in uploading product logo", request)
            Alert(Alert.danger, self.getVendorProductWorkflow().getErrors(), request)

        return self.redirect("certification-specification-details",
                             queryDict=None,
                             paramList=[self.program, self.certificationID])
