# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#

import os, smtplib, mimetypes
from rhcert.compatability import StringIO

from email import encoders
from email.mime.audio import MIMEAudio
from email.mime.base import MIMEBase
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText

from .view import View


class MailTo(View):
    def __init__(self):
        View.__init__(self)

    def compileFormData(self):
        rpath = self.parameters["rpath"]
        self.data["path"] = rpath
        self.data["filename"] = os.path.basename(rpath)
        systemHeader = ""
        info = rpath.split("/")
        if len(info) >= 10:
            systemHeader ="%s  %s Arch: %s  OS: %s %s\n" % (info[5], info[6], info[8], info[9], info[10])
        self.data["system"] = systemHeader

    def compileConfirm(self):
        self.data["send-to"] = self.getParameter("send-to")
        self.data["path"] = self.getParameter("rpath")

    def validateParameters(self):
        if not self.getParameter("rpath"):
            self.appendError("Error: rpath not specified")
        elif not os.path.exists(self.getParameter("rpath")):
            self.appendError("Error: could not locate %s" % self.getQueryParameter("rpath"))
        return not self.getErrors()

    def createMessage(self):
        # Create the enclosing (outer) message
        self.message = MIMEMultipart()
        self.message["Subject"] = "Red Hat Certification Results"
        self.message["From"] = self.environment.getServerEMail()
        self.message["To"] = self.getParameter("send-to")

    def addAttachment(self):
        path = self.getParameter("rpath")
        mimeType, encoding = mimetypes.guess_type(path)
        if mimeType is None or encoding is not None:
            mimeType = 'application/octet-stream'
        mainType, subType = mimeType.split('/', 1)
        if mainType == 'text':
            attachmentFile = open(path)
            part = MIMEText(attachmentFile.read(), _subtype=subType)
            attachmentFile.close()
        elif mainType == 'audio':
                attachmentFile = open(path, 'rb')
                part = MIMEAudio(attachmentFile.read(), _subtype=subType)
                attachmentFile.close()
        else:
            attachmentFile = open(path, 'rb')
            part = MIMEBase(mainType, subType)
            part.set_payload(attachmentFile.read())
            attachmentFile.close()
            encoders.encode_base64(part)
        part.add_header('Content-Disposition', 'attachment', filename=os.path.basename(path))
        self.message.attach(part)

    def sendMessage(self):
        mailServer = smtplib.SMTP('localhost')
        mailServer.sendmail(self.environment.getServerEMail(), [self.getParameter("send-to")], self.message.as_string())
        mailServer.quit()

    def view(self, request):
        View.view(self, request)

        # server email address and smtp host must be set
        if not self.environment.getServerEMail():
            self.appendError("Error: server email address is not set")
        if not self.environment.getServerSMTPHost():
            self.appendError("Error: server smtp host is not set")

        if not self.validateParameters():
            return self.data

        # form submitted?
        if self.getParameter("to"):
            self.createMessage()
            self.addAttachment()
            self.sendMessage()
            self.compileConfirm()
        else:
            self.compileFormData()

        return self.data()
