# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Rajasi Kulkarni
#
from django.http import JsonResponse

from .view import View
from .alert import Alert


class Makes(View):
    """ Get all the makes of a vendor """

    def __init__(self):
        View.__init__(self)
        self.loginRequired = True

    def serve(self, request, vendor_id):
        View.authenticate(self, request)
        result = View.view(self, request)
        if type(result) != dict:
            return result
        makes = self.getConnection(request).getCertificationWorkflow().getMakesByVendor(vendor_id)
        #if self.getConnection(request).getCertificationWorkflow().getErrors():
        #    Alert()
        """
        CWE is allowing to create pass through on public as well as private makes

        Ex:
        [{'is_public': 1, 'name': 'HPE ProLiant', 'id': 700}
         {'is_public': 1, 'name': <xmlrpclib.Binary instance at 0x563264886b00>, 'id': 451}
        ]
        filter names that do not have 'names' as string, this is bad data

        """
        if makes:
           makes_filtered = [make for make in makes if isinstance(make.get("name"), str)]
           makes_response = {"makes": makes_filtered}
        else:
           makes_response = dict()
        return JsonResponse(makes_response)
