# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols <gnichols@redhat.com>
#
import gzip
from lxml import etree
from rhcert.compatability import StringIO

from wsgi.page import Page


class ResultsXML(Page):
    """ Results - render results via XSLT """

    def __init__(self, request, environment):
        Page.__init__(self, request, environment)

    def serve(self):
        """ override Page.serve for XSLT """

        print("calling getParameters")
        xsltParameters = self.getXSLTParameters()
        print("doing transform")
        body = self.doTransform(xsltParameters)
        length = 0
        for line in body:
            length += len(line)
        print("length of body: %s" % length)
        responseHeaders = [('Content-Type', 'text/%s' % self.getQueryParameter("content")),
                       ('Content-Length', str(length))]
        status = '200 OK'

        return (status, responseHeaders, body)

    def getXSLTParameters(self):
        #defaults
        defaultQueryParameters = { "sheet": "default", "content":"xml", "rpath":self.environment.getResultsPath()}
        xsltParameters = { "devices":"\'hide\'", "device-classes": "\'hide\'", "rpath":"\'%s\'" % self.environment.getResultsPath(), "server-email":"\'%s\'" % self.environment.getServerEMail()}
        # add default parameters if they're not in the query string
        for key in defaultQueryParameters.keys():
            if key not in self.query:
                self.query[key] = defaultQueryParameters[key]

        # overide default xslt parameters with those from the query string
        for key in self.query.keys():
            if self.getQueryParameter(key):
                if key == "rpath":
                    print("rpath from query: %s" % self.getQueryParameter(key))
                xsltParameters[key] = "\'%s\'" % self.getQueryParameter(key)
                print("xsltParameter %s=%s" % (key, xsltParameters[key]))
        return xsltParameters

    def doTransform(self, xsltParameters):
        outputString = StringIO()
        print("in doTransform")
        xslfile = "%s/xsl/%s.xsl" % (self.environment.getServerDirectory(), self.getQueryParameter("sheet"))
        # we need huge_tree set as some attachments are 24MB+
        parser = etree.XMLParser(huge_tree=True)
        xslt = etree.parse(xslfile, parser)
        print("parsed %s" % xslfile)
        print(xslt)
        access = etree.XSLTAccessControl(read_file=True, write_file=False, create_dir=False, read_network=False, write_network=False)
        transform = etree.XSLT(xslt, access_control=access)
        print("created the transform")
        resultsPath = self.environment.getResultsPath()

        if "rpath" in self.query:
            resultsPath = self.query["rpath"][0]
        print("rpath = %s" % resultsPath)
        try:
            if resultsPath[-2:] == "gz":
                results = gzip.open(resultsPath, 'rb')
            else:
                results = open(resultsPath, 'r')

            results = etree.parse(results, parser)
            output = transform(results, **xsltParameters)
            output.write(outputString, pretty_print=True)

        except IOError as e:
            outputString.write("<pre>There are no test results\n")
            outputString.write("(%s)\n</pre>" % e)

        return outputString.getvalue()
