# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
import os

from rhcert.tags import Tags
from rhcert.host import Host


from .sandbox import Sandbox


class Results(Sandbox):
    """ presents the sandbox results document listing UI page """

    def __init__(self):
        Sandbox.__init__(self)

    def view(self, request):
        result = Sandbox.view(self, request)
        if type(result) != dict:
            return result
        # otherwise
        self.data["bodyEvents"] = "onbeforeunload='resetSelectors();'"

        self.__viewCertification()

        return self.data

    def __viewCertification(self):
        resultsDocuments = self.getStore().getResultsDocumentsFor(self.certification, skipEmpty=False)
        if resultsDocuments:
            hosts = dict()
            paths = dict()
            for (path, document) in resultsDocuments.items():
                host = Host(document.getOS(Tags.hostname), ipAddress=document.getOS(Tags.ip_address))
                hosts[host.getConnection()] = host
                if host.getConnection() not in paths:
                    paths[host.getConnection()] = list()
                paths[host.getConnection()].append(path)

                self.data["hosts"] = list()
            for (connection, host) in hosts.items():
                hostDictionary = dict()
                self.data["hosts"].append(hostDictionary)
                hostDictionary["name"] =  host.getName()
                hostDictionary["connection"] =  connection
                hostDictionary["latestPath"] = paths[connection][0]



