# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols
#
from django.shortcuts import render

from rhcert.tags import Tags
from ..view import View


class Sandbox(View):
    """ presents the sandbox UI page """

    def __init__(self):
        View.__init__(self)

    def serve(self, request, template, program, sandboxID):
        self.sandboxID = sandboxID
        self.program = program
        (_, self.certification) = self.getConnection(request).getStore().getCertification(program, self.sandboxID)
        if self.certification:
            (vendorID, productID) = self.certification.getPartnerAndProductID()
        result = self.view(request)
        if type(result) != dict:
            return result
        # otherwise
        return render(request, template, result)

    def view(self, request):
        View.view(self, request)
        if not self.certification:
            self.appendError("No sandbox found for program %s ID %s" % self.program, self.sandboxID)
            return self.data

        # if this is a call to this abstract view, redirect to default, depending on program and workflow
        if type(self) is Sandbox:
            return self.redirect("sandbox-results", queryDict=None, paramList=[self.program,  self.sandboxID])

        # otherwise - call from subpage
        self.data["certificationID"] = self.sandboxID
        self.data["certificationProgram"] = self.program
        self.data.update(self.getWorkflowParameters(self.certification))

        vendors = self.certification.getVendors(notRedHat=True)
        if vendors:
            self.vendor = vendors[0]
            self.data["vendor"] = self.vendor
            products = self.vendor.getProducts()
            if products:
                self.product = products[0]
                self.data["product"] = self.product

        self.data["productCertification"] = self.certification.getProductCertification()

        self.data["os"] = dict()
        for parameter in [Tags.product, Tags.release]:
            self.data["os"][parameter] = self.certification.getOS(parameter)

        return self.data
