# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Rajasi Kulkarni <rajkulka@redhat.com>
#
# Implementation of the wsgi for updating VendorProduct

from django.shortcuts import render
from django.http import HttpResponseRedirect

from .update import Update
from ..alert import Alert


class UpdateProduct(Update):

    def __init__(self):
        Update.__init__(self)

    def view(self, request):
        Update.view(self, request)
        self.productID = self.getParameter("productID")
        self.vendorID = self.getParameter("vendorID")
        self.program = self.getParameter("program")
        self.certificationID = self.getParameter("certificationID")
        self.chosenFile = self.getParameter("chosenFile")

        if self.productID and self.vendorID:
            self.vendor = self.getConnection().getVendorProducts().getVendorByID(self.vendorID)
            if self.vendor:
                self.product = self.vendor.getProduct(self.productID)

            # Check if there is any file to upload
            if self.chosenFile:
                # API call to upload file
                self.cweFileResponse = self.getEngineWorkflow().uploadFileToCertification(self.certificationID,
                                                                                self.getParameter("isSpec"),
                                                                                self.getParameter("description"),
                                                                                self.chosenFile.name,
                                                                                self.chosenFile.read(),
                                                                                self.chosenFile.content_type)
                if not self.getErrors() and self.cweFileResponse:
                    Alert(Alert.success, "File uploaded successfully", request)
                else:
                    Alert(Alert.danger, "Error in file upload", request)
                    Alert(Alert.danger, self.getEngineWorkflow().getErrors(), request)

            # API call to update Product details
            self.cweResponse = self.getVendorProductWorkflow().updateProduct(self.vendor, self.program, self.getPostDictionary())
            if not self.getErrors() and self.cweResponse:
                Alert(Alert.success, "Product details updated successfully", request)
            else:
                Alert(Alert.danger, "Error in updating Product details", request)
                Alert(Alert.danger, self.getVendorProductWorkflow().getErrors(), request)

            return self.redirect("certification-specification-details",
                                 queryDict=None,
                                 paramList=[self.program, self.certificationID])

