# Copyright (c) 2017 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Rajasi Kulkarni <rajkulka@redhat.com>
#
# Implementation of the wsgi for updating test results

import requests
from django.http import HttpResponseRedirect

from rhcert.model.resultsdocument import ResultsDocument

from .update import Update
from ..alert import Alert


class UpdateTestResults(Update):

    def __init__(self):
        Update.__init__(self)
        self.fileType = None
        self.document = None

    def view(self, request):

        Update.view(self, request)
        self.path = self.getParameter("rpath")
        self.hostname = self.getParameter("hostname")
        self.program = self.getParameter("certificationProgram")
        self.certification_id = self.getParameter("certificationID")
        self.plantime = self.getParameter("plantime")

        if self.path:
            error = ""
            (self.fileType, self.document) = self.getStore().getCertificationInfo(self.path, error)
            if error:
                self.appendError(error)
            elif self.fileType == "results":
                try:
                    # Load the results file
                    self.resultsDocument = ResultsDocument()
                    print("loading " + self.path)
                    self.resultsDocument.load(self.path)
                except Exception as err:
                    self.appendError("Error: Could not load results")

                else:
                    # Update the deferred service calls
                    updated = self.microServices.update(self.resultsDocument)
                    if updated:
                        Alert(Alert.success, "Test results updated successfully", request)
                        self.resultsDocument.save()
                    else:
                        self.appendError("Error in updating test results")
        if self.getParameter("isSandbox"):
             return self.redirect("sandbox-activity-results",
                                  queryDict=None,
                                  paramList=[self.program,
                                             self.certification_id,
                                             self.hostname,
                                             self.plantime])
        return self.redirect("assign",
                             queryDict=None,
                             paramList=[self.program,
                                        self.certification_id,
                                        self.hostname,
                                        self.plantime])
