# Copyright (c) 2018 Red Hat, Inc. All rights reserved. This copyrighted material
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Shreyas Patil
#
import struct
import os

#------------------------------------------------------------------#
# Ref: http://www.ietf.org/rfc/rfc1952.txt                         #
# Ref: https://github.com/python/cpython/blob/2.7/Lib/gzip.py#L195 #
#------------------------------------------------------------------#
# RFC 1952       GZIP File Format Specification          May 1996  #
#                                                                  #
#                                                                  #
# 2.3.1. Member header and trailer                                 #
#                                                                  #
# ID1 (IDentification 1)                                           #
# ID2 (IDentification 2)                                           #
#    These have the fixed values ID1 = 31 (0x1f, \037), ID2 = 139  #
#    (0x8b, \213), to identify the file as being in gzip format.   #
#------------------------------------------------------------------#
def checkGzippedFile(uploadedFile):
    # NOTE: To verify Gzip file read and try to find the bytes to decide
    # whether we have valid Gzip file.
    if uploadedFile.content_type in ('application/gzip', 'application/x-gzip'):
        fileName = ''
        uploaded_gzip_header = uploadedFile.read(2)

        # Unpacking the values as per byte ordering in Big-endian system.
        # https://docs.python.org/2/library/struct.html
        expected_gzip_header = (31, 139)
        uploaded_gzip_header = struct.unpack('>BB', uploaded_gzip_header)

        # Not a Gzip file use XML as the file. So we will rename file to XML
        # as it is expected format for the file
        if uploaded_gzip_header != expected_gzip_header:
            fileName, _ =  os.path.splitext(uploadedFile.name) # Remove .gz from file name

        else:
            fileName = uploadedFile.name

        # Return the file cursor to Zeroth position
        uploadedFile.seek(0)
        return ((uploaded_gzip_header == expected_gzip_header), fileName)

    return ( False, uploadedFile.name)
