<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:variable name="results" select="HHHH" />

    <xsl:template match="/certification-test">
        <!--  <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
        -->
        <html lang="en">

<head>
            <title>Red Hat Certification:
                <xsl:value-of select="certification/os/product"/>
                <xsl:value-of select="certification/os/release"/></title>
            <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
            <link rel="shortcut icon" href="/rhcert/images/favicon.ico"/>
            <link rel="stylesheet" href="/rhcert/css/rcue.min.css"/>
            <!--[if lt IE 9]>
            <script src="/rhcert/js/html5shiv.min.js">//</script>
            <script src="/rhcert/js/respond.min.js">//</script>
            <![endif]-->
            <!-- IE8 requires jQuery and Bootstrap JS to load in head to prevent rendering bugs -->
            <!-- IE8 requires jQuery v1.x -->
            <!-- <script src="//code.jquery.com/jquery-1.10.2.min.js">//</script>
        -->
        <script src="/rhcert/js/jquery-1.10.2.min.js">//</script>
        <script src="/rhcert/js/bootstrap.min.js">//</script>
        <script src="/rhcert/js/bootstrap-select.min.js">//</script>
        <script src="/rhcert/js/jquery.dataTables.js">//</script>
        <script src="/rhcert/js/patternfly.min.js">//</script>
        <script src="/rhcert/js/rhcert.js">//</script>
</head>

<body>
    <div class="container-fluid">
        <div class="row">
            <nav class="navbar navbar-default navbar-pf" role="navigation">
                <div class="navbar-header">
                    <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse-1">
                        <span class="sr-only">Toggle navigation</span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                    </button>
                    <a class="navbar-brand" href="/">
                        <img src="/rhcert/images/logo.svg" alt="Red Hat Certification" width="151"/>
                    </a>
                </div>
            </nav>
        </div>
        <div class="page-header">
            <h1>Test Results</h1>
        </div>

        <dl class="dl-horizontal">
            <xsl:if test="hardware/vendor != ''">
                <dt>Host Vendor</dt>
                <dd>
                    <xsl:value-of select="hardware/vendor"/>
                </dd>
            </xsl:if>
            <xsl:if test="hardware/model != ''">
                <dt>Host Model</dt>
                <dd>
                    <xsl:value-of select="hardware/model"/>
                </dd>
            </xsl:if>
            <dt>Host Arch</dt>
            <dd>
                <xsl:value-of select="hardware/arch"/>
            </dd>
            <dt>Base OS</dt>
            <dd>
                <xsl:value-of select="certification/os/product"/>
                <xsl:text disable-output-escaping="yes">
                    <![CDATA[&nbsp;]]>
                </xsl:text>
                <xsl:value-of select="certification/os/release"/>
                (
                <xsl:value-of select="certification/os/name"/>
                )
            </dd>
            <dt>Certification ID</dt>
            <dd>
                <xsl:value-of select="certification/@id"/>
            </dd>
            <dt>Certification Type</dt>
            <dd>
                <xsl:value-of select="certification/@type"/>
            </dd>
            <dt>rhcert</dt>
            <dd>
                <xsl:value-of select="@rhcert-version"/>
                release
                <xsl:value-of select="@rhcert-release" />
            </dd>
            <dt>Date</dt>
            <dd>
                <xsl:value-of select="@plan-time" />
            </dd>
            <dt>Host</dt>
            <dd>
                <xsl:value-of select="certification/os/hostname"/>
                <xsl:if test="certification/os/ip-address">
                    (<xsl:value-of select="certification/os/ip-address"/>)
                </xsl:if>
            </dd>
            <xsl:if test="@state">
                <dt>State</dt>
                <dd>
                    <xsl:value-of select="@state"/>
                </dd>
            </xsl:if>
        </dl>

        <h3>
            <small>See Also</small>
        </h3>

        <ul class="list-inline">
            <li>
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>certification/</xsl:text>
                        <xsl:value-of select="certification/@type"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="certification/@id"/>
                    </xsl:attribute>
                    Certification
                </a>
            </li>
            <li>
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>results?sheet=summary</xsl:text>
                        <xsl:text>&amp;content=html</xsl:text>
                        <xsl:text>&amp;rpath=</xsl:text>
                        <xsl:value-of select="$rpath"/>
                    </xsl:attribute>
                    Results
                </a>
            </li>
            <li>
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>results?sheet=device&amp;rpath=</xsl:text>
                        <xsl:value-of select="$rpath"/>
                    </xsl:attribute>
                    Devices
                </a>
            </li>
            <li>
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>results?sheet=attachments</xsl:text>
                        <xsl:text>&amp;content=html</xsl:text>
                        <xsl:text>&amp;rpath=</xsl:text>
                        <xsl:value-of select="$rpath"/>
                    </xsl:attribute>
                    Attachments
                </a>
            </li>
        </ul>


        <form method="post" action="run" class="table-responsive">
            <input type="hidden" name="rpath">
                <xsl:attribute name="value">
                    <xsl:value-of select="$rpath"/>
                </xsl:attribute>
            </input>
            <table class="table table-striped table-bordered table-hover">
                <thead>
                    <tr>
                        <th colspan="2" align="right">Run:</th>
                        <xsl:call-template name="runTableHeader">
                            <xsl:with-param name="currentRun" select="1"/>
                            <xsl:with-param name="runs" select="@number-of-runs"/>
                        </xsl:call-template>
                    </tr>
                </thead>
                <xsl:for-each select="/certification-test/test">
                    <xsl:if test="not(@status) or (@status != 'deleted')">
                        <xsl:variable name="currentTest" select="." />
                        <tr>
                            <td>
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:text>results?sheet=run&amp;test=</xsl:text>
                                        <xsl:value-of select="@name"/>
                                        <xsl:if test="parameters/property[@name='device'] != ''">
                                            <xsl:text>&amp;device=</xsl:text>
                                            <xsl:value-of select="parameters/property[@name='device']"/>
                                        </xsl:if>
                                        <xsl:text>&amp;rpath=</xsl:text>
                                        <xsl:value-of select="$rpath"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="@path"/>
                                </a>
                            </td>
                            <td>
                                <xsl:text disable-output-escaping="yes">
                                    <![CDATA[&nbsp;]]>
                                </xsl:text>
                                <xsl:if  test="parameters/property[@name='device'] != ''">
                                    <xsl:choose>
                                        <xsl:when test="parameters/property[@name='udi'] != ''">
                                            <a>
                                                <xsl:attribute name="href">
                                                    <xsl:text>results?sheet=device&amp;udi=</xsl:text>
                                                    <xsl:value-of select="parameters/property[@name='udi']"/>
                                                    <xsl:text>&amp;rpath=</xsl:text>
                                                    <xsl:value-of select="$rpath"/>
                                                </xsl:attribute>
                                                <xsl:value-of select="parameters/property[@name='device']"/>
                                            </a>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="parameters/property[@name='device']"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:if>
                            </td>
                            <xsl:call-template name="runTableRow">
                                <xsl:with-param name="currentRunNumber" select="1"/>
                                <xsl:with-param name="runs" select="/certification-test/@number-of-runs"/>
                                <xsl:with-param name="currentTest" select="$currentTest"/>
                                <xsl:with-param name="currentRun" select="$currentTest/run"/>
                            </xsl:call-template>
                            <xsl:if test="not(/certification-test/@state) or (/certification-test/@state != 'closed')">
                                <td>
                                    <xsl:choose>
                                        <xsl:when test="tag = 'interactive'">
                                            <button type="submit" formaction="interactive" class="btn btn-sm btn-primary">
                                                <xsl:attribute name="name">
                                                    <xsl:text>interactive:</xsl:text>
                                                    <xsl:value-of select="@name"/>
                                                    <xsl:if test="parameters/property[@name='device'] != ''">
                                                        <xsl:text> --device </xsl:text>
                                                        <xsl:value-of select="parameters/property[@name='device']"/>
                                                    </xsl:if>
                                                </xsl:attribute>
                                                Run Interactive
                                            </button>
                                        </xsl:when>
                                        <xsl:when test="@mandatory = 'pre'">
                                            <input type="checkbox" name="new-run" disabled="disabled" checked="checked">
                                                <xsl:attribute name="value">
                                                    <xsl:value-of select="@name"/>
                                                </xsl:attribute>
                                                pre-run
                                            </input>
                                            <input type="hidden" name="new-run">
                                                <xsl:attribute name="value">
                                                    <xsl:value-of select="@name"/>
                                                </xsl:attribute>
                                            </input>
                                        </xsl:when>
                                        <xsl:when test="@mandatory = 'post'">
                                            <input type="checkbox" name="new-run" disabled="disabled" checked="checked">
                                                <xsl:attribute name="value">
                                                    <xsl:value-of select="@name"/>
                                                </xsl:attribute>
                                                post-run
                                            </input>
                                            <input type="hidden" name="new-run">
                                                <xsl:attribute name="value">
                                                    <xsl:value-of select="@name"/>
                                                </xsl:attribute>
                                            </input>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <input type="checkbox" name="new-run">
                                                <xsl:attribute name="value">
                                                    <xsl:value-of select="@name"/>
                                                    <xsl:if test="parameters/property[@name='device'] != ''">
                                                        <xsl:text> --device </xsl:text>
                                                        <xsl:value-of select="parameters/property[@name='device']"/>
                                                    </xsl:if>
                                                </xsl:attribute>
                                            </input>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </td>
                            </xsl:if>
                        </tr>
                    </xsl:if>
                </xsl:for-each>
            </table>
        </form>

        <hr/>
        <ul class="list-inline">
            <li>
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>/rhcert-results/</xsl:text>
                        <xsl:value-of select="substring-after($rpath, '/var/www/rhcert/store/results/')"/>
                    </xsl:attribute>
                    Download
                </a>
            </li>
            <xsl:if  test="$server-email != ''">
                <li>
                    <a>
                        <xsl:attribute name="href">
                            <xsl:text>mailto?rpath=</xsl:text>
                            <xsl:value-of select="$rpath"/>
                        </xsl:attribute>
                        E-Mail
                    </a>
                </li>
            </xsl:if>
            <li>
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>submit?rpath=</xsl:text>
                        <xsl:value-of select="$rpath"/>
                    </xsl:attribute>
                    Submit
                </a>
            </li>
            <li>
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>save?rpath=</xsl:text>
                        <xsl:value-of select="$rpath"/>
                    </xsl:attribute>
                    Save
                </a>
            </li>
            <li>
                <a>
                    <xsl:attribute name="href">
                        <xsl:text>delete?rpath=</xsl:text>
                        <xsl:value-of select="$rpath"/>
                    </xsl:attribute>
                    Delete
                </a>
            </li>
        </ul>
    </div>
</body>
</html>
</xsl:template>

<xsl:template name="runTableHeader">
<xsl:param name="currentRun"/>
<xsl:param name="runs"/>
<xsl:choose>
    <xsl:when test="$currentRun &lt;= $runs">
    <th>
        <xsl:value-of select="$currentRun"/>
    </th>
    <xsl:call-template name="runTableHeader">
        <xsl:with-param name="currentRun" select="$currentRun + 1"/>
        <xsl:with-param name="runs" select="$runs"/>
    </xsl:call-template>
    </xsl:when>
    <xsl:when test="not(@state) or (@state !='closed')">
        <th>
            <input type="submit" value="Run Selected" class="btn btn-sm btn-primary"/>
            <xsl:text disable-output-escaping="yes">
                    <![CDATA[&nbsp;]]>
            </xsl:text>
            <input type="checkbox" name="debug" value="low"/>
            <xsl:text disable-output-escaping="yes">
                    <![CDATA[&nbsp;]]>
            </xsl:text>debug
        </th>
    </xsl:when>
</xsl:choose>
</xsl:template>

<xsl:template name="runTableRow">
<xsl:param name="currentRunNumber"/>
<xsl:param name="runs"/>
<xsl:param name="currentTest"/>
<xsl:param name="currentRun"/>
<xsl:if test="$currentRunNumber &lt;= $runs">
<xsl:choose>
<xsl:when test="number($currentRun/@number) = number($currentRunNumber)">
    <td>
        <a>
            <xsl:attribute name="href">
                <xsl:text>results?sheet=run&amp;test=</xsl:text>
                <xsl:value-of select="$currentTest/@name"/>
                <xsl:text>&amp;run=</xsl:text>
                <xsl:value-of select="$currentRun/@number"/>
                <xsl:if test="parameters/property[@name='device'] != ''">
                    <xsl:text>&amp;device=</xsl:text>
                    <xsl:value-of select="parameters/property[@name='device']"/>
                </xsl:if>
                <xsl:text>&amp;rpath=</xsl:text>
                <xsl:value-of select="$rpath"/>
            </xsl:attribute>
            <xsl:value-of select="$currentRun/summary" />
        </a>
    </td>
    <xsl:call-template name="runTableRow">
        <xsl:with-param name="currentRunNumber" select="$currentRunNumber + 1"/>
        <xsl:with-param name="runs" select="$runs"/>
        <xsl:with-param name="currentTest" select="$currentTest"/>
        <xsl:with-param name="currentRun" select="$currentRun/following::run"/>
    </xsl:call-template>
</xsl:when>
<xsl:otherwise>
    <td>
        <xsl:text disable-output-escaping="yes">
            <![CDATA[&nbsp;]]>
        </xsl:text>
    </td>
    <xsl:call-template name="runTableRow">
        <xsl:with-param name="currentRunNumber" select="$currentRunNumber + 1"/>
        <xsl:with-param name="runs" select="$runs"/>
        <xsl:with-param name="currentTest" select="$currentTest"/>
        <xsl:with-param name="currentRun" select="$currentRun"/>
    </xsl:call-template>
</xsl:otherwise>
</xsl:choose>
</xsl:if>
</xsl:template>

</xsl:stylesheet>
