# Copyright (c) 2014 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Greg Nichols 
#

from ..view import View
from rhcert.model.vendorproducts import VendorProductsDocument
from rhcert.environment import Environment


class CWEPerf(View):

    def __init__(self):
        View.__init__(self)
        self.loginRequired = True

    def view(self, request):
        View.authenticate(self, request)
        self.request = request
        self.getConnection(request) # get data connection

        if self.askingForParameters():
            return self.data

        self.run()
        return self.data

    def askingForParameters(self):
        # defaults
        self.count = 10
        self.program = "all"
        if self.getParameter("count"):
            self.count = int(self.getParameter("count"))
        if self.getParameter("program"):
            self.program = self.getParameter("program")
        self.data["program"] = self.program
        return False

    def run(self):
        self.data["phase"] = Environment().getPhase()

        # get user's vendors and products
        vendorProducts = self.getConnection().getVendorProductWorkflow().list()
        self.appendErrors(self.getVendorProductWorkflow().getErrors())
        if self.getErrors() and not vendorProducts:
            return False
        vendorProductsDocument = VendorProductsDocument()
        vendorProductsDocument.new()
        if vendorProducts:
            self.getConnection().getVendorProductWorkflow().updateVendorProducts(vendorProducts, vendorProductsDocument)

        self.data["VendorProduct_list"] = {
                                "time": self.getConnection().getVendorProductWorkflow().getCallTime(),
                                "vendorCount": len(vendorProductsDocument.getVendors()),
                                "productCount": len(vendorProducts)
                                }

        # get a list  of certifications filtered by program
        program = None
        if self.program != "all":
            program = self.program
        certifications = self.getConnection().getCertificationWorkflow().getCertifications(program=program)
        self.data["Cert_getCertifications"] = {
                            "time": self.getConnection().getCertificationWorkflow().getCallTime(),
                            "count": len(certifications)
                            }

        # get details
        totalTime = minTime = maxTime = 0
        count = 0
        workflow = self.getConnection().getCertificationWorkflow()
        workflow.clearErrors()
        self.data["valid"] = list()
        for certification in certifications:
            if program and certification.get("program") != program:
                continue
            workflow.get(certification.get("program"),certification.get("cert_id") )
            if workflow.getErrors():
                self.appendErrors(workflow.getErrors())
                workflow.clearErrors()
                continue
            time = self.getConnection().getCertificationWorkflow().getCallTime()
            totalTime += time
            if minTime == 0 or time < minTime:
                minTime = time
            if maxTime == 0 or time > maxTime:
                maxTime = time
            count = count +1
            self.data["valid"].append((certification.get("program"),certification.get("cert_id")))
            if count >= self.count:
                break

        self.data["Cert_get"] = {
            "totalTime": totalTime,
            "minTime": minTime,
            "maxTime": maxTime,
            "aveTime": totalTime/count if count else 0,
            "count": count
            }
 


