<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:output method="xml" indent="yes"/>

	<xsl:template match="/certification-test">
		<package-summary>

			<xsl:if test="@hwcert-version">
				<hwcert-version>
					<xsl:value-of select="@hwcert-version"/>
				</hwcert-version>
			</xsl:if>

			<xsl:if test="@hwcert-release">
				<hwcert-release>
					<xsl:value-of select="@hwcert-release"/>
				</hwcert-release>
			</xsl:if>

			<xsl:if test="@rhcert-version">
				<rhcert-version>
					<xsl:value-of select="@rhcert-version"/>
				</rhcert-version>
			</xsl:if>

			<xsl:if test="@rhcert-release">
				<rhcert-release>
					<xsl:value-of select="@rhcert-release"/>
				</rhcert-release>
			</xsl:if>

			<xsl:if test="@v7-version">
				<v7-version>
					<xsl:value-of select="@v7-version"/>
				</v7-version>
			</xsl:if>

			<xsl:if test="@v7-release">
				<v7-release>
					<xsl:value-of select="@v7-release"/>
				</v7-release>
			</xsl:if>

			<os>
				<name>
					<xsl:value-of select="certification/os/product"/>
				</name>
				<release>
					<xsl:value-of select="certification/os/release"/>
				</release>
			</os>

			<xsl:variable name="test-server-ip" select="hardware/test-server/@ip-address"/>
			<test-server ip-address="{$test-server-ip}">
				<xsl:value-of select="hardware/test-server"/>
			</test-server>
			<vendor>
				<xsl:value-of select="hardware/vendor"/>
			</vendor>
			<make>
				<xsl:value-of select="hardware/make"/>
			</make>
			<model>
				<xsl:value-of select="hardware/model"/>
			</model>
			<arch>
				<xsl:value-of select="hardware/arch"/>
			</arch>

			<xsl:for-each select="test">

				<xsl:if test="run">

					<xsl:variable name="test-name" select="@name"/>

					<xsl:variable name="test-path" select="@path"/>

					<xsl:variable name="last-run" select="run[last()]"/>

					<xsl:variable name="test-result" select="$last-run/summary/@data-value"/>
					<test name="{$test-name}" path="{$test-path}" result="{$test-result}">

						<xsl:copy-of select="$last-run/parameters"/>

						<xsl:copy-of select="$last-run/attachment"/>

						<xsl:value-of select="string($last-run/output/text())"/>

						<xsl:for-each select="$last-run/output/command">
							<xsl:text>---------------------------------------------------</xsl:text><br/>
							<xsl:value-of select="string(./@command)"/><br/>

							<xsl:if test="./stdout">
								<xsl:text>stdout:  </xsl:text><br/>
								<xsl:value-of select="string(./stdout/text())"/><br/>
							</xsl:if>
							<xsl:if test="./stderr">
								<xsl:text>stderr:  </xsl:text><br/>
								<xsl:value-of select="string(./stderr/text())"/><br/>
							</xsl:if>
							<xsl:if test="./regex">
								<xsl:text>regex:  </xsl:text><br/>
								<xsl:value-of select="string(./regex/text())"/><br/>
							</xsl:if>

							<xsl:if test="./@return-value">
								<xsl:text>returned:  </xsl:text>
								<xsl:value-of select="string(./@return-value)"/><br/>
							</xsl:if>

							<xsl:variable name="count" select="position()+1"/>
							<xsl:value-of select="string($last-run/output/text()[$count])"/>
						</xsl:for-each>

						<xsl:for-each select="$last-run/output/output">

							<xsl:variable name="subtest-name" select="@name"/>

							<xsl:variable name="subtest-result" select="summary/@data-value"/>
							<subtest name="{$subtest-name}" result="{$subtest-result}">
								<xsl:variable name="subcount" select="position()"/>
								<xsl:value-of select="string($last-run/output/output[$subcount]/text())"/>

								<xsl:for-each select="./command">
									<xsl:text>---------------------------------------------------</xsl:text><br/>
									<xsl:value-of select="string(./@command)"/><br/>
									<xsl:if test="./stdout">
										<xsl:text>stdout:  </xsl:text><br/>
										<xsl:value-of select="string(./stdout/text())"/><br/>
									</xsl:if>
									<xsl:if test="./stderr">
										<xsl:text>stderr:  </xsl:text><br/>
										<xsl:value-of select="string(./stderr/text())"/><br/>
									</xsl:if>
									<xsl:if test="./regex">
										<xsl:text>regex:  </xsl:text><br/>
										<xsl:value-of select="string(./regex/text())"/><br/>
									</xsl:if>

									<xsl:if test="./@return-value">
										<xsl:text>returned:  </xsl:text>
										<xsl:value-of select="string(./@return-value)"/><br/>
									</xsl:if>

									<xsl:variable name="count" select="position()+1"/>
									<xsl:value-of select="string($last-run/output/output[$subcount]/text()[$count])"/>
								</xsl:for-each>
							</subtest>
						</xsl:for-each>
					</test>
				</xsl:if>
			</xsl:for-each>

		</package-summary>
	</xsl:template>
</xsl:stylesheet>
